
**`ABSESpy` framework is based on many excellent open-source projects:**

| Package       | Version           | Purpose                                               |
|---------------|-------------------|-------------------------------------------------------|
| python        | ">=3.9,<3.12"          | Core programming language used for development        |
| netcdf4       | ">=1.6"           | To read and write NetCDF and HDF5 files               |
| hydra-core    | "~1.3"           | For managing application configurations               |
| mesa-geo      | ">=0.6"            | To create spatially explicit agent-based models       |
| xarray        | "~2024"        | To work with labelled multi-dimensional arrays        |
| fiona         | ">1.8"     | For reading and writing vector data (shapefiles, etc) |
| loguru         | "~0.7"     | For better logging |
| rioxarray         | ">=0.13"     | Operating raster data and xarray |
| pendulum         | "~2"     | For time control |
| geopandas         | "~0"     | For shapefile geo-data operating |

!!! Warning

    The above table may not be up-in-date, please refer full dependencies and their versions in the `pyproject.toml` file.
